# Example file for upstream/metadata.
# See https://wiki.debian.org/UpstreamMetadata for more info/fields.
# Below an example based on a github project.

# Bug-Database: https://github.com/<user>/ffmpeg-normalize/issues
# Bug-Submit: https://github.com/<user>/ffmpeg-normalize/issues/new
# Changelog: https://github.com/<user>/ffmpeg-normalize/blob/master/CHANGES
# Documentation: https://github.com/<user>/ffmpeg-normalize/wiki
# Repository-Browse: https://github.com/<user>/ffmpeg-normalize
# Repository: https://github.com/<user>/ffmpeg-normalize.git
